@@ -1,31 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -63,10 +66,6 @@
 #include "error_messages.h"
 
 #include <QtQml/qqmlextensionplugin.h>
-#include <QtQml/qqml.h>
-#include <QtQml/private/qqmlvaluetype_p.h>
-#include <QtQml/private/qqmlglobal_p.h>
-#include <QtQml/private/qqmlmetatype_p.h>
 
 #include <QtCore/QDebug>
 
@@ -146,22 +145,21 @@ public:
             // Introduction of 5.3 version; existing 5.0 exports automatically become available under 5.3 as well
             // 5.3 is committed QML API despite missing release of QtLocation 5.3
 
-            // Register the 5.4 types
-            // Implicitly registers 5.3
-            minor = 4;
-            // For now there are no new types; just reregister one existing 5.0 type
+            // Register the 5.5 types
+            // Implicitly registers 5.3 & 5.4
+            minor = 5;
             qmlRegisterUncreatableType<QDeclarativeGeoMapType, 1>(uri, major, minor, "MapType",
                                         QStringLiteral("MapType is not intended instantiable by developer."));
 
             //registrations below are version independent
-            qRegisterMetaType<QPlaceCategory>("QPlaceCategory");
-            qRegisterMetaType<QPlace>("QPlace");
-            qRegisterMetaType<QPlaceIcon>("QPlaceIcon");
-            qRegisterMetaType<QPlaceRatings>("QPlaceRatings");
-            qRegisterMetaType<QPlaceSupplier>("QPlaceSupplier");
-            qRegisterMetaType<QPlaceUser>("QPlaceUser");
-            qRegisterMetaType<QPlaceAttribute>("QPlaceAttribute");
-            qRegisterMetaType<QPlaceContactDetail>("QPlaceContactDetail");
+            qRegisterMetaType<QPlaceCategory>();
+            qRegisterMetaType<QPlace>();
+            qRegisterMetaType<QPlaceIcon>();
+            qRegisterMetaType<QPlaceRatings>();
+            qRegisterMetaType<QPlaceSupplier>();
+            qRegisterMetaType<QPlaceUser>();
+            qRegisterMetaType<QPlaceAttribute>();
+            qRegisterMetaType<QPlaceContactDetail>();
         } else {
             qDebug() << "Unsupported URI given to load location QML plugin: " << QLatin1String(uri);
         }
