@@ -1,39 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -41,16 +36,21 @@
 
 #include "qdeclarativegeomapgesturearea_p.h"
 #include "qdeclarativegeomap_p.h"
+#include "qgeomapcontroller_p.h"
 #include "error_messages.h"
 
 #include <QtGui/QGuiApplication>
 #include <QtGui/qevent.h>
+#include <QtGui/QWheelEvent>
 #include <QtGui/QStyleHints>
 #include <QtQml/qqmlinfo.h>
+#include <QtQuick/QQuickWindow>
 #include <QPropertyAnimation>
 #include <QDebug>
+#include <QtPositioning/private/qgeoprojection_p.h>
 #include "math.h"
 #include "qgeomap_p.h"
+#include "qdoublevector2d_p.h"
 
 #define QML_MAP_FLICK_DEFAULTMAXVELOCITY 2500
 #define QML_MAP_FLICK_MINIMUMDECELERATION 500
@@ -221,6 +221,8 @@ QT_BEGIN_NAMESPACE
     \qmlproperty bool QtLocation::MapGestureArea::isPanActive
 
     This read-only property holds whether any pan gesture (panning or flicking) is active.
+
+    \note Change notifications for this property were introduced in Qt 5.5.
 */
 
 /*!
@@ -232,17 +234,9 @@ QT_BEGIN_NAMESPACE
     \list
     \li MapGestureArea.NoGesture - Don't support any additional gestures (value: 0x0000).
     \li MapGestureArea.ZoomGesture - Support the map zoom gesture (value: 0x0001).
-    \li MapGestureArea.RotationGesture - Support the map rotation gesture (value: 0x0002).
-    \li MapGestureArea.TiltGesture - Support the map tilt gesture (value: 0x0004).
-    \li MapGestureArea.PanGesture  - Support the map pan gesture (value: 0x0008).
-    \li MapGestureArea.FlickGesture  - Support the map flick gesture (value: 0x0010).
+    \li MapGestureArea.PanGesture  - Support the map pan gesture (value: 0x0002).
+    \li MapGestureArea.FlickGesture  - Support the map flick gesture (value: 0x0004).
     \endlist
-
-    For the extremist, one may OR flag the RotationGesture or TiltGesture
-    but these come with absolutely no warranty or guarantees at the moment
-    (may be removed, changed, moved around)
-
-    \note For the time being, only MapGestureArea.ZoomGesture is supported.
 */
 
 /*!
@@ -253,17 +247,7 @@ QT_BEGIN_NAMESPACE
 
     It is an indicative measure calculated from the dimensions of the
     map area, roughly corresponding how much zoom level could change with
-    maximum pinch zoom. Default value is 2.0, maximum value is 10.0
-*/
-
-/*!
-    \qmlproperty real MapGestureArea::rotationFactor
-
-    This property holds the rotation factor for zoom, essentially meant to be used for setting
-    the rotation sensitivity.
-
-    It is an indicative measure; the default value 1.0 means the map roughly follows the fingers,
-    whereas 2.0 means rotating twice as fast. Maximum value is 5.0.
+    maximum pinch zoom. Default value is 4.0, maximum value is 10.0
 */
 
 /*!
@@ -277,7 +261,9 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmlsignal QtLocation::MapGestureArea::pinchStarted(PinchEvent event)
 
-    Raised when a pinch gesture is started.
+    This signal is emitted when a pinch gesture is started.
+
+    The corresponding handler is \c onPinchStarted.
 
     \sa pinchUpdated, pinchFinished
 */
@@ -285,8 +271,10 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmlsignal QtLocation::MapGestureArea::pinchUpdated(PinchEvent event)
 
-    Once a pinch has begun this event gets raised as the user moves her fingers
-    across the map.
+    This signal is emitted as the user's fingers move across the map,
+    after the \l pinchStarted signal is emitted.
+
+    The corresponding handler is \c onPinchUpdated.
 
     \sa pinchStarted, pinchFinished
 */
@@ -294,7 +282,9 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmlsignal QtLocation::MapGestureArea::pinchFinished(PinchEvent event)
 
-    The end of a pinch gesture is signaled by this event.
+    This signal is emitted at the end of a pinch gesture.
+
+    The corresponding handler is \c onPinchFinished.
 
     \sa pinchStarted, pinchUpdated
 */
@@ -302,37 +292,59 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmlsignal QtLocation::MapGestureArea::panStarted()
 
-    This handler is called when the view begins moving due to user
+    This signal is emitted when the view begins moving due to user
     interaction. Typically this means that the user is dragging a finger -
     or a mouse with one of more mouse buttons pressed - on the map.
+
+    The corresponding handler is \c onPanStarted.
 */
 
 /*!
     \qmlsignal QtLocation::MapGestureArea::panFinished()
 
-    This handler is called when the view stops moving due to user
-    interaction.  If a flick was generated, this handler will
-    be triggered once the flick stops.  If a flick was not
-    generated, the handler will be triggered when the
+    This signal is emitted when the view stops moving due to user
+    interaction.  If a flick was generated, this signal is
+    emitted when the flick stops.  If a flick was not
+    generated, this signal is emitted when the
     user stops dragging - that is a mouse or touch release.
 
+    The corresponding handler is \c onPanFinished.
+
 */
 
 /*!
     \qmlsignal QtLocation::MapGestureArea::flickStarted()
 
-    This handler is called when the view is flicked.  A flick
+    This signal is emitted when the view is flicked.  A flick
     starts from the point that the mouse or touch is released,
     while still in motion.
+
+    The corresponding handler is \c onFlichStarted.
 */
 
 /*!
     \qmlsignal QtLocation::MapGestureArea::flickFinished()
 
-    This handler is called when the view stops moving due to a flick.
+    This signal is emitted when the view stops moving due to a flick.
     The order of panFinished() and flickFinished() is not specified.
+
+    The corresponding handler is \c onFlickFinished.
 */
 
+static void registerQGeoCoordinateInterpolator()
+{
+    // required by QPropertyAnimation
+    qRegisterAnimationInterpolator<QGeoCoordinate>(geoCoordinateInterpolator);
+}
+Q_CONSTRUCTOR_FUNCTION(registerQGeoCoordinateInterpolator)
+
+static void unregisterQGeoCoordinateInterpolator()
+{
+    qRegisterAnimationInterpolator<QGeoCoordinate>(
+                (QVariant (*)(const QGeoCoordinate &, const QGeoCoordinate &, qreal))0);
+}
+Q_DESTRUCTOR_FUNCTION(unregisterQGeoCoordinateInterpolator)
+
 QDeclarativeGeoMapGestureArea::QDeclarativeGeoMapGestureArea(QDeclarativeGeoMap *map, QObject *parent)
     : QObject(parent),
       declarativeMap_(map),
@@ -347,8 +359,8 @@ QDeclarativeGeoMapGestureArea::QDeclarativeGeoMapGestureArea(QDeclarativeGeoMap
     touchPointState_ = touchPoints0;
     pinchState_ = pinchInactive;
     panState_ = panInactive;
-
 }
+
 /*!
     \internal
 */
@@ -360,8 +372,6 @@ void QDeclarativeGeoMapGestureArea::setMap(QGeoMap *map)
     pan_.animation_ = new QPropertyAnimation(map_->mapController(), "center", this);
     pan_.animation_->setEasingCurve(QEasingCurve(QEasingCurve::OutQuad));
     connect(pan_.animation_, SIGNAL(finished()), this, SLOT(endFlick()));
-    connect(this, SIGNAL(movementStopped()),
-            map_, SLOT(cameraStopped()));
 }
 
 QDeclarativeGeoMapGestureArea::~QDeclarativeGeoMapGestureArea()
@@ -384,10 +394,6 @@ void QDeclarativeGeoMapGestureArea::setActiveGestures(ActiveGestures activeGestu
     if (activeGestures == activeGestures_)
         return;
     activeGestures_ = activeGestures;
-    if (activeGestures_ & RotationGesture)
-        qmlInfo(this) << QCoreApplication::translate(CONTEXT_NAME, PINCH_ROTATE_GESTURE_ACTIVATED);
-    if (activeGestures_ & TiltGesture)
-        qmlInfo(this) << QCoreApplication::translate(CONTEXT_NAME, PINCH_TILT_GESTURE_ACTIVATED);
     emit activeGesturesChanged();
 }
 
@@ -471,18 +477,44 @@ void QDeclarativeGeoMapGestureArea::setPanEnabled(bool enabled)
 
 /*!
     \internal
-    called internally when plugin's limits change. somewhat dodgy but
-    initialization order complicates the zoom limit settings a bit (for example when is
-    it possible to check against mapping plugins' limits)
-*/
-void QDeclarativeGeoMapGestureArea::zoomLevelLimits(qreal min, qreal max)
+    Used internally to set the minimum zoom level of the gesture area.
+    The caller is responsible to only send values that are valid
+    for the map plugin. Negative values are ignored.
+ */
+void QDeclarativeGeoMapGestureArea::setMinimumZoomLevel(qreal min)
 {
-    if (pinch_.zoom.minimum == -1.0 || min > pinch_.zoom.minimum)
+    if (min >= 0)
         pinch_.zoom.minimum = min;
-    if (pinch_.zoom.maximum == -1.0 || max < pinch_.zoom.maximum)
+}
+
+/*!
+   \internal
+ */
+qreal QDeclarativeGeoMapGestureArea::minimumZoomLevel() const
+{
+    return pinch_.zoom.minimum;
+}
+
+/*!
+    \internal
+    Used internally to set the maximum zoom level of the gesture area.
+    The caller is responsible to only send values that are valid
+    for the map plugin. Negative values are ignored.
+ */
+void QDeclarativeGeoMapGestureArea::setMaximumZoomLevel(qreal max)
+{
+    if (max >= 0)
         pinch_.zoom.maximum = max;
 }
 
+/*!
+   \internal
+ */
+qreal QDeclarativeGeoMapGestureArea::maximumZoomLevel() const
+{
+    return pinch_.zoom.maximum;
+}
+
 /*!
     \internal
 */
@@ -502,25 +534,6 @@ void QDeclarativeGeoMapGestureArea::setMaximumZoomLevelChange(qreal maxChange)
     emit maximumZoomLevelChangeChanged();
 }
 
-/*!
-    \internal
-*/
-qreal QDeclarativeGeoMapGestureArea::rotationFactor() const
-{
-    return pinch_.rotation.factor;
-}
-
-/*!
-    \internal
-*/
-void QDeclarativeGeoMapGestureArea::setRotationFactor(qreal factor)
-{
-    if (pinch_.rotation.factor == factor ||  factor < 0 || factor > 5)
-        return;
-    pinch_.rotation.factor = factor;
-    emit rotationFactorChanged();
-}
-
 /*!
     \internal
 */
@@ -547,118 +560,82 @@ void QDeclarativeGeoMapGestureArea::setFlickDeceleration(qreal deceleration)
 /*!
     \internal
 */
-QTouchEvent::TouchPoint makeTouchPointFromMouseEvent(QMouseEvent *event, Qt::TouchPointState state)
+QTouchEvent::TouchPoint* createTouchPointFromMouseEvent(QMouseEvent *event, Qt::TouchPointState state)
 {
     // this is only partially filled. But since it is only partially used it works
     // more robust would be to store a list of QPointFs rather than TouchPoints
-    QTouchEvent::TouchPoint newPoint;
-    newPoint.setPos(event->localPos());
-    newPoint.setScenePos(event->windowPos());
-    newPoint.setScreenPos(event->screenPos());
-    newPoint.setState(state);
-    newPoint.setId(0);
+    QTouchEvent::TouchPoint* newPoint = new QTouchEvent::TouchPoint();
+    newPoint->setPos(event->localPos());
+    newPoint->setScenePos(event->windowPos());
+    newPoint->setScreenPos(event->screenPos());
+    newPoint->setState(state);
+    newPoint->setId(0);
     return newPoint;
 }
 
 /*!
     \internal
 */
-bool QDeclarativeGeoMapGestureArea::mousePressEvent(QMouseEvent *event)
+void QDeclarativeGeoMapGestureArea::handleMousePressEvent(QMouseEvent *event)
 {
-    if (!(enabled_ && activeGestures_))
-        return false;
+    m_mousePoint.reset(createTouchPointFromMouseEvent(event, Qt::TouchPointPressed));
+    if (m_touchPoints.isEmpty()) update();
+    event->accept();
+}
 
-    touchPoints_.clear();
-    touchPoints_ << makeTouchPointFromMouseEvent(event, Qt::TouchPointPressed);
+/*!
+    \internal
+*/
+void QDeclarativeGeoMapGestureArea::handleMouseMoveEvent(QMouseEvent *event)
+{
+    m_mousePoint.reset(createTouchPointFromMouseEvent(event, Qt::TouchPointMoved));
+    if (m_touchPoints.isEmpty()) update();
+    event->accept();
+}
 
+/*!
+    \internal
+*/
+void QDeclarativeGeoMapGestureArea::handleMouseReleaseEvent(QMouseEvent *event)
+{
+    m_mousePoint.reset(createTouchPointFromMouseEvent(event, Qt::TouchPointReleased));
+    if (m_touchPoints.isEmpty()) update();
+    event->accept();
+}
+
+/*!
+    \internal
+*/
+void QDeclarativeGeoMapGestureArea::handleMouseUngrabEvent()
+{
+    m_mousePoint.reset();
     update();
-    return true;
 }
 
 /*!
     \internal
 */
-bool QDeclarativeGeoMapGestureArea::mouseMoveEvent(QMouseEvent *event)
+void QDeclarativeGeoMapGestureArea::handleTouchUngrabEvent()
 {
-    if (!(enabled_ && activeGestures_))
-        return false;
-
-    touchPoints_.clear();
-
-    touchPoints_ << makeTouchPointFromMouseEvent(event, Qt::TouchPointMoved);
+    m_touchPoints.clear();
     update();
-    return true;
 }
 
 /*!
     \internal
 */
-bool QDeclarativeGeoMapGestureArea::mouseReleaseEvent(QMouseEvent *)
+void QDeclarativeGeoMapGestureArea::handleTouchEvent(QTouchEvent *event)
 {
-    if (!(enabled_ && activeGestures_))
-        return false;
-
-    touchPoints_.clear();
+    m_touchPoints.clear();
+    for (int i = 0; i < event->touchPoints().count(); ++i)
+        m_touchPoints << event->touchPoints().at(i);
     update();
-    return true;
 }
 
-/*!
-    \internal
-*/
-void QDeclarativeGeoMapGestureArea::touchEvent(QTouchEvent *event)
+void QDeclarativeGeoMapGestureArea::handleWheelEvent(QWheelEvent *event)
 {
-    switch (event->type()) {
-    case QEvent::TouchBegin:
-    case QEvent::TouchUpdate:
-        touchPoints_.clear();
-        for (int i = 0; i < event->touchPoints().count(); ++i) {
-            if (!(event->touchPoints().at(i).state() & Qt::TouchPointReleased)) {
-                touchPoints_ << event->touchPoints().at(i);
-            }
-        }
-        update();
-        break;
-    case QEvent::TouchEnd:
-        touchPoints_.clear();
-        update();
-        break;
-    default:
-        // no-op
-        break;
-    }
-}
-
-/*!
-    \internal
-*/
-bool QDeclarativeGeoMapGestureArea::filterMapChildMouseEvent(QMouseEvent *event)
-{
-    bool used = false;
-    switch (event->type()) {
-    case QEvent::MouseButtonPress:
-        used = mousePressEvent(event);
-        break;
-    case QEvent::MouseButtonRelease:
-        used = mouseReleaseEvent(event);
-        break;
-    case QEvent::MouseMove:
-        used = mouseMoveEvent(event);
-        break;
-    default:
-        used = false;
-        break;
-    }
-    return used && (isPanActive() || isPinchActive());
-}
-
-/*!
-    \internal
-*/
-bool QDeclarativeGeoMapGestureArea::filterMapChildTouchEvent(QTouchEvent *event)
-{
-    touchEvent(event);
-    return isPanActive() || isPinchActive();
+    declarativeMap_->setZoomLevel(qBound(minimumZoomLevel(), declarativeMap_->zoomLevel() + event->angleDelta().y() * qreal(0.001), maximumZoomLevel()));
+    event->accept();
 }
 
 /*!
@@ -668,7 +645,6 @@ void QDeclarativeGeoMapGestureArea::clearTouchData()
 {
     velocityX_ = 0;
     velocityY_ = 0;
-    pressTime_.start();
     sceneCenter_.setX(0);
     sceneCenter_.setY(0);
     touchCenterCoord_.setLongitude(0);
@@ -700,17 +676,34 @@ void QDeclarativeGeoMapGestureArea::updateVelocityList(const QPointF &pos)
     }
 }
 
+/*!
+    \internal
+*/
+
+bool QDeclarativeGeoMapGestureArea::isActive() const
+{
+    return isPanActive() || isPinchActive();
+}
+
 /*!
     \internal
 */
 // simplify the gestures by using a state-machine format (easy to move to a future state machine)
 void QDeclarativeGeoMapGestureArea::update()
 {
+    if (!map_) return;
     // First state machine is for the number of touch points
+
+    //combine touch with mouse event
+    m_allPoints.clear();
+    m_allPoints << m_touchPoints;
+    if (m_allPoints.isEmpty() && !m_mousePoint.isNull())
+        m_allPoints << *m_mousePoint.data();
+
     touchPointStateMachine();
 
     // Parallel state machine for pinch
-    if (isPinchActive() || (enabled_ && pinch_.enabled && (activeGestures_ & (ZoomGesture | TiltGesture | RotationGesture))))
+    if (isPinchActive() || (enabled_ && pinch_.enabled && (activeGestures_ & (ZoomGesture))))
         pinchStateMachine();
 
     // Parallel state machine for pan (since you can pan at the same time as pinching)
@@ -729,30 +722,30 @@ void QDeclarativeGeoMapGestureArea::touchPointStateMachine()
     // Transitions:
     switch (touchPointState_) {
     case touchPoints0:
-        if (touchPoints_.count() == 1) {
+        if (m_allPoints.count() == 1) {
             clearTouchData();
             startOneTouchPoint();
             touchPointState_ = touchPoints1;
-        } else if (touchPoints_.count() == 2) {
+        } else if (m_allPoints.count() >= 2) {
             clearTouchData();
             startTwoTouchPoints();
             touchPointState_ = touchPoints2;
         }
         break;
     case touchPoints1:
-        if (touchPoints_.count() == 0) {
+        if (m_allPoints.count() == 0) {
             touchPointState_ = touchPoints0;
-        } else if (touchPoints_.count() == 2) {
-            touchCenterCoord_ = map_->screenPositionToCoordinate(sceneCenter_, false);
+        } else if (m_allPoints.count() == 2) {
+            touchCenterCoord_ = map_->itemPositionToCoordinate(QDoubleVector2D(sceneCenter_), false);
             startTwoTouchPoints();
             touchPointState_ = touchPoints2;
         }
         break;
     case touchPoints2:
-        if (touchPoints_.count() == 0) {
+        if (m_allPoints.count() == 0) {
             touchPointState_ = touchPoints0;
-        } else if (touchPoints_.count() == 1) {
-            touchCenterCoord_ = map_->screenPositionToCoordinate(sceneCenter_, false);
+        } else if (m_allPoints.count() == 1) {
+            touchCenterCoord_ = map_->itemPositionToCoordinate(QDoubleVector2D(sceneCenter_), false);
             startOneTouchPoint();
             touchPointState_ = touchPoints1;
         }
@@ -777,10 +770,10 @@ void QDeclarativeGeoMapGestureArea::touchPointStateMachine()
 */
 void QDeclarativeGeoMapGestureArea::startOneTouchPoint()
 {
-    sceneStartPoint1_ = touchPoints_.at(0).scenePos();
+    sceneStartPoint1_ = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
     lastPos_ = sceneStartPoint1_;
     lastPosTime_.start();
-    QGeoCoordinate startCoord = map_->screenPositionToCoordinate(sceneStartPoint1_, false);
+    QGeoCoordinate startCoord = map_->itemPositionToCoordinate(QDoubleVector2D(sceneStartPoint1_), false);
     // ensures a smooth transition for panning
     startCoord_.setLongitude(startCoord_.longitude() + startCoord.longitude() -
                              touchCenterCoord_.longitude());
@@ -793,7 +786,7 @@ void QDeclarativeGeoMapGestureArea::startOneTouchPoint()
 */
 void QDeclarativeGeoMapGestureArea::updateOneTouchPoint()
 {
-    sceneCenter_ = touchPoints_.at(0).scenePos();
+    sceneCenter_ = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
     updateVelocityList(sceneCenter_);
 }
 
@@ -803,12 +796,12 @@ void QDeclarativeGeoMapGestureArea::updateOneTouchPoint()
 */
 void QDeclarativeGeoMapGestureArea::startTwoTouchPoints()
 {
-    sceneStartPoint1_ = touchPoints_.at(0).scenePos();
-    sceneStartPoint2_ = touchPoints_.at(1).scenePos();
+    sceneStartPoint1_ = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
+    sceneStartPoint2_ = declarativeMap_->mapFromScene(m_allPoints.at(1).scenePos());
     QPointF startPos = (sceneStartPoint1_ + sceneStartPoint2_) * 0.5;
     lastPos_ = startPos;
     lastPosTime_.start();
-    QGeoCoordinate startCoord = map_->screenPositionToCoordinate(startPos, false);
+    QGeoCoordinate startCoord = map_->itemPositionToCoordinate(QDoubleVector2D(startPos), false);
     startCoord_.setLongitude(startCoord_.longitude() + startCoord.longitude() -
                              touchCenterCoord_.longitude());
     startCoord_.setLatitude(startCoord_.latitude() + startCoord.latitude() -
@@ -820,13 +813,12 @@ void QDeclarativeGeoMapGestureArea::startTwoTouchPoints()
 */
 void QDeclarativeGeoMapGestureArea::updateTwoTouchPoints()
 {
-    QPointF p1 = touchPoints_.at(0).scenePos();
-    QPointF p2 = touchPoints_.at(1).scenePos();
+    QPointF p1 = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
+    QPointF p2 = declarativeMap_->mapFromScene(m_allPoints.at(1).scenePos());
     qreal dx = p1.x() - p2.x();
     qreal dy = p1.y() - p2.y();
     distanceBetweenTouchPoints_ = sqrt(dx * dx + dy * dy);
     sceneCenter_ = (p1 + p2) / 2;
-
     updateVelocityList(sceneCenter_);
 
     twoTouchAngle_ = QLineF(p1, p2).angle();
@@ -834,18 +826,6 @@ void QDeclarativeGeoMapGestureArea::updateTwoTouchPoints()
         twoTouchAngle_ -= 360;
 }
 
-/*!
-    \internal
-*/
-void QDeclarativeGeoMapGestureArea::setPinchActive(bool active)
-{
-    if ((active && pinchState_ == pinchActive) || (!active && pinchState_ != pinchActive))
-        return;
-    pinchState_ = active ? pinchActive : pinchInactive;
-    emit pinchActiveChanged();
-}
-
-
 /*!
     \internal
 */
@@ -855,25 +835,43 @@ void QDeclarativeGeoMapGestureArea::pinchStateMachine()
     // Transitions:
     switch (pinchState_) {
     case pinchInactive:
-        if (canStartPinch()) {
-            startPinch();
-            setPinchActive(true);
+        if (m_allPoints.count() >= 2) {
+            if (canStartPinch()) {
+                startPinch();
+                pinchState_ = pinchActive;
+            } else {
+                pinchState_ = pinchInactiveTwoPoints;
+            }
+        }
+        break;
+    case pinchInactiveTwoPoints:
+        if (m_allPoints.count() <= 1) {
+            pinchState_ = pinchInactive;
+        } else {
+            if (canStartPinch()) {
+                startPinch();
+                pinchState_ = pinchActive;
+            }
         }
         break;
     case pinchActive:
-        if (touchPoints_.count() <= 1) {
+        if (m_allPoints.count() <= 1) {
             endPinch();
-            setPinchActive(false);
+            pinchState_ = pinchInactive;
         }
         break;
     }
     // This line implements an exclusive state machine, where the transitions and updates don't
     // happen on the same frame
-    if (pinchState_ != lastState)
-         return;
+    if (pinchState_ != lastState) {
+        emit pinchActiveChanged();
+        return;
+    }
+
     // Update
     switch (pinchState_) {
     case pinchInactive:
+    case pinchInactiveTwoPoints:
         break; // do nothing
     case pinchActive:
         updatePinch();
@@ -888,9 +886,9 @@ bool QDeclarativeGeoMapGestureArea::canStartPinch()
 {
     const int startDragDistance = qApp->styleHints()->startDragDistance();
 
-    if (touchPoints_.count() >= 2) {
-        QPointF p1 = touchPoints_.at(0).scenePos();
-        QPointF p2 = touchPoints_.at(1).scenePos();
+    if (m_allPoints.count() >= 2) {
+        QPointF p1 = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
+        QPointF p2 = declarativeMap_->mapFromScene(m_allPoints.at(1).scenePos());
         if (qAbs(p1.x()-sceneStartPoint1_.x()) > startDragDistance
          || qAbs(p1.y()-sceneStartPoint1_.y()) > startDragDistance
          || qAbs(p2.x()-sceneStartPoint2_.x()) > startDragDistance
@@ -899,7 +897,7 @@ bool QDeclarativeGeoMapGestureArea::canStartPinch()
             pinch_.event.setAngle(twoTouchAngle_);
             pinch_.event.setPoint1(p1);
             pinch_.event.setPoint2(p2);
-            pinch_.event.setPointCount(touchPoints_.count());
+            pinch_.event.setPointCount(m_allPoints.count());
             pinch_.event.setAccepted(true);
             emit pinchStarted(&pinch_.event);
             return pinch_.event.accepted();
@@ -914,17 +912,13 @@ bool QDeclarativeGeoMapGestureArea::canStartPinch()
 void QDeclarativeGeoMapGestureArea::startPinch()
 {
     pinch_.startDist = distanceBetweenTouchPoints_;
-    pinch_.zoom.previous = 1.0;
-    pinch_.tilt.previous = 0.0;
+    pinch_.zoom.previous = declarativeMap_->zoomLevel();
     pinch_.lastAngle = twoTouchAngle_;
-    pinch_.rotation.angle = 0.0;
 
-    pinch_.lastPoint1 = touchPoints_.at(0).scenePos();
-    pinch_.lastPoint2 = touchPoints_.at(1).scenePos();
+    pinch_.lastPoint1 = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
+    pinch_.lastPoint2 = declarativeMap_->mapFromScene(m_allPoints.at(1).scenePos());
 
     pinch_.zoom.start = declarativeMap_->zoomLevel();
-    pinch_.rotation.start = declarativeMap_->bearing();
-    pinch_.tilt.start = declarativeMap_->tilt();
 }
 
 /*!
@@ -948,15 +942,14 @@ void QDeclarativeGeoMapGestureArea::updatePinch()
         da -= 360;
     else if (da < -180)
         da += 360;
-    pinch_.rotation.angle -= da;
     pinch_.event.setCenter(declarativeMap_->mapFromScene(sceneCenter_));
     pinch_.event.setAngle(twoTouchAngle_);
 
-    pinch_.lastPoint1 = touchPoints_.at(0).scenePos();
-    pinch_.lastPoint2 = touchPoints_.at(1).scenePos();
+    pinch_.lastPoint1 = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
+    pinch_.lastPoint2 = declarativeMap_->mapFromScene(m_allPoints.at(1).scenePos());
     pinch_.event.setPoint1(pinch_.lastPoint1);
     pinch_.event.setPoint2(pinch_.lastPoint2);
-    pinch_.event.setPointCount(touchPoints_.count());
+    pinch_.event.setPointCount(m_allPoints.count());
     pinch_.event.setAccepted(true);
 
     pinch_.lastAngle = twoTouchAngle_;
@@ -968,37 +961,7 @@ void QDeclarativeGeoMapGestureArea::updatePinch()
         qreal perPinchMaximumZoomLevel = qMin(pinch_.zoom.start + pinch_.zoom.maximumChange, pinch_.zoom.maximum);
         newZoomLevel = qMin(qMax(perPinchMinimumZoomLevel, newZoomLevel), perPinchMaximumZoomLevel);
         declarativeMap_->setZoomLevel(newZoomLevel);
-    }
-    if (activeGestures_ & TiltGesture && pinch_.zoom.minimum >= 0 && pinch_.zoom.maximum >= 0) {
-        // Note: tilt is not yet supported.
-        qreal newTilt = pinch_.tilt.previous;
-        if (distanceBetweenTouchPoints_) {
-            newTilt =
-                    // How much further/closer the current touchpoints are (in pixels) compared to pinch start
-                    ((distanceBetweenTouchPoints_ - pinch_.startDist)  *
-                     //  How much one pixel corresponds in units of tilt degrees (and multiply by above delta)
-                     (pinch_.tilt.maximumChange / ((declarativeMap_->width() + declarativeMap_->height()) / 2))) +
-                    // Add to starting tilt.
-                    pinch_.tilt.start;
-        }
-        qreal perPinchMinimumTilt = qMax(pinch_.tilt.start - pinch_.tilt.maximumChange, pinch_.tilt.minimum);
-        qreal perPinchMaximumTilt = qMin(pinch_.tilt.start + pinch_.tilt.maximumChange, pinch_.tilt.maximum);
-        newTilt = qMin(qMax(perPinchMinimumTilt, newTilt), perPinchMaximumTilt);
-        pinch_.tilt.previous = newTilt;
-        declarativeMap_->setTilt(newTilt);
-    }
-    if (activeGestures_ & RotationGesture) {
-        bool unlimitedRotation = (pinch_.rotation.minimum == 0.0 && pinch_.rotation.maximum == 0.0);
-        if ((pinch_.rotation.start >= pinch_.rotation.minimum && pinch_.rotation.start <= pinch_.rotation.maximum) || unlimitedRotation)  {
-            qreal r = pinch_.rotation.angle * pinch_.rotation.factor + pinch_.rotation.start;
-            if (!unlimitedRotation)
-                r = qMin(qMax(pinch_.rotation.minimum,r), pinch_.rotation.maximum);
-            if (r > 360.0)
-                r -= 360;
-            if (r < -360.0)
-                r += 360.0;
-            declarativeMap_->setBearing(r);
-        }
+        pinch_.zoom.previous = newZoomLevel;
     }
 }
 
@@ -1007,11 +970,12 @@ void QDeclarativeGeoMapGestureArea::updatePinch()
 */
 void QDeclarativeGeoMapGestureArea::endPinch()
 {
-    QPointF pinchCenter = declarativeMap_->mapFromScene(sceneCenter_);
-    pinch_.event.setCenter(pinchCenter);
+    QPointF p1 = declarativeMap_->mapFromScene(pinch_.lastPoint1);
+    QPointF p2 = declarativeMap_->mapFromScene(pinch_.lastPoint2);
+    pinch_.event.setCenter((p1 + p2) / 2);
     pinch_.event.setAngle(pinch_.lastAngle);
-    pinch_.event.setPoint1(declarativeMap_->mapFromScene(pinch_.lastPoint1));
-    pinch_.event.setPoint2(declarativeMap_->mapFromScene(pinch_.lastPoint2));
+    pinch_.event.setPoint1(p1);
+    pinch_.event.setPoint2(p2);
     pinch_.event.setAccepted(true);
     pinch_.event.setPointCount(0);
     emit pinchFinished(&pinch_.event);
@@ -1028,28 +992,39 @@ void QDeclarativeGeoMapGestureArea::panStateMachine()
     // Transitions
     switch (panState_) {
     case panInactive:
-        if (canStartPan())
+        if (canStartPan()) {
+            // Update startCoord_ to ensure smooth start for panning when going over startDragDistance
+            QGeoCoordinate newStartCoord = map_->itemPositionToCoordinate(QDoubleVector2D(sceneCenter_), false);
+            startCoord_.setLongitude(newStartCoord.longitude());
+            startCoord_.setLatitude(newStartCoord.latitude());
             panState_ = panActive;
+        }
         break;
     case panActive:
-        if (touchPoints_.count() == 0) {
+        if (m_allPoints.count() == 0) {
             panState_ = panFlick;
             if (!tryStartFlick())
             {
                 panState_ = panInactive;
                 // mark as inactive for use by camera
-                if (pinchState_ == pinchInactive)
-                    emit movementStopped();
+                if (pinchState_ == pinchInactive) {
+                    emit panFinished();
+                    map_->prefetchData();
+                }
             }
         }
         break;
     case panFlick:
-        if (touchPoints_.count() > 0) { // re touched before movement ended
+        if (m_allPoints.count() > 0) { // re touched before movement ended
             endFlick();
             panState_ = panActive;
         }
         break;
     }
+
+    if (panState_ != lastState)
+        emit panActiveChanged();
+
     // Update
     switch (panState_) {
     case panInactive: // do nothing
@@ -1069,17 +1044,16 @@ void QDeclarativeGeoMapGestureArea::panStateMachine()
 */
 bool QDeclarativeGeoMapGestureArea::canStartPan()
 {
-    if (touchPoints_.count() == 0 || (activeGestures_ & PanGesture) == 0)
+    if (m_allPoints.count() == 0 || (activeGestures_ & PanGesture) == 0)
         return false;
 
     // Check if thresholds for normal panning are met.
     // (normal panning vs flicking: flicking will start from mouse release event).
-    const int startDragDistance = qApp->styleHints()->startDragDistance();
-    QPointF p1 = touchPoints_.at(0).scenePos();
+    const int startDragDistance = qApp->styleHints()->startDragDistance() * 2;
+    QPointF p1 = declarativeMap_->mapFromScene(m_allPoints.at(0).scenePos());
     int dyFromPress = int(p1.y() - sceneStartPoint1_.y());
     int dxFromPress = int(p1.x() - sceneStartPoint1_.x());
-    if ((qAbs(dyFromPress) > startDragDistance || qAbs(dxFromPress) > startDragDistance
-         || pressTime_.elapsed() > 200))
+    if ((qAbs(dyFromPress) >= startDragDistance || qAbs(dxFromPress) >= startDragDistance))
         return true;
     return false;
 }
@@ -1089,16 +1063,14 @@ bool QDeclarativeGeoMapGestureArea::canStartPan()
 */
 void QDeclarativeGeoMapGestureArea::updatePan()
 {
-    QPointF startPoint = map_->coordinateToScreenPosition(startCoord_, false);
+    QPointF startPoint = map_->coordinateToItemPosition(startCoord_, false).toPointF();
     int dx = static_cast<int>(sceneCenter_.x() - startPoint.x());
     int dy = static_cast<int>(sceneCenter_.y() - startPoint.y());
     QPointF mapCenterPoint;
     mapCenterPoint.setY(map_->height() / 2.0  - dy);
     mapCenterPoint.setX(map_->width() / 2.0 - dx);
-    AnimatableCoordinate animationStartCoordinate;
-    animationStartCoordinate.setCoordinate(map_->screenPositionToCoordinate(mapCenterPoint, false));
+    QGeoCoordinate animationStartCoordinate = map_->itemPositionToCoordinate(QDoubleVector2D(mapCenterPoint), false);
     map_->mapController()->setCenter(animationStartCoordinate);
-
 }
 
 /*!
@@ -1146,22 +1118,19 @@ bool QDeclarativeGeoMapGestureArea::tryStartFlick()
 /*!
     \internal
 */
-// FIXME:
-// - not left right / up down flicking, so if map is rotated, will act unintuitively
 void QDeclarativeGeoMapGestureArea::startFlick(int dx, int dy, int timeMs)
 {
     if (timeMs < 0)
         return;
-    AnimatableCoordinate animationStartCoordinate = map_->mapController()->center();
-    QGeoCoordinate coordinate = animationStartCoordinate.coordinate();
+
+    QGeoCoordinate animationStartCoordinate = map_->mapController()->center();
 
     if (pan_.animation_->state() == QPropertyAnimation::Running)
         pan_.animation_->stop();
-    AnimatableCoordinate animationEndCoordinate = map_->mapController()->center();
+    QGeoCoordinate animationEndCoordinate = map_->mapController()->center();
     pan_.animation_->setDuration(timeMs);
-    coordinate.setLongitude(coordinate.longitude() - (dx / pow(2.0, map_->mapController()->zoom())));
-    coordinate.setLatitude(coordinate.latitude() + (dy / pow(2.0, map_->mapController()->zoom())));
-    animationEndCoordinate.setCoordinate(coordinate);
+    animationEndCoordinate.setLongitude(animationStartCoordinate.longitude() - (dx / pow(2.0, map_->mapController()->zoom())));
+    animationEndCoordinate.setLatitude(animationStartCoordinate.latitude() + (dy / pow(2.0, map_->mapController()->zoom())));
     pan_.animation_->setStartValue(QVariant::fromValue(animationStartCoordinate));
     pan_.animation_->setEndValue(QVariant::fromValue(animationEndCoordinate));
     pan_.animation_->start();
@@ -1175,10 +1144,11 @@ void QDeclarativeGeoMapGestureArea::stopPan()
     if (panState_ == panFlick) {
         endFlick();
     } else if (panState_ == panActive) {
+        panState_ = panInactive;
         emit panFinished();
-        emit movementStopped();
+        emit panActiveChanged();
+        map_->prefetchData();
     }
-    panState_ = panInactive;
 }
 
 /*!
@@ -1191,14 +1161,14 @@ void QDeclarativeGeoMapGestureArea::endFlick()
         pan_.animation_->stop();
     emit flickFinished();
     panState_ = panInactive;
-    emit movementStopped();
+    emit panActiveChanged();
+    map_->prefetchData();
 }
 
 
 
 
 
-
 #include "moc_qdeclarativegeomapgesturearea_p.cpp"
 
 QT_END_NAMESPACE
