@@ -1,39 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -50,7 +45,7 @@ QT_BEGIN_NAMESPACE
     \instantiates QDeclarativeGeoServiceProvider
     \inqmlmodule QtLocation
     \ingroup qml-QtLocation5-common
-    \since Qt Location 5.0
+    \since Qt Location 5.5
 
     \brief The Plugin type describes a Location based services plugin.
 
@@ -75,13 +70,13 @@ QT_BEGIN_NAMESPACE
 
     The following snippet shows a Plugin object being created with the
     \l required and \l preferred properties set. This Plugin will attach to the
-    first plugin found plugin that supports both mapping and geocoding, and will
-    prefer plugins named "nokia" or "foo" to any others.
+    first found plugin that supports both mapping and geocoding, and will
+    prefer plugins named "here" or "osm" to any others.
 
     \code
     Plugin {
         id: plugin
-        preferred: ["nokia", "foo"]
+        preferred: ["here", "osm"]
         required: Plugin.AnyMappingFeatures | Plugin.AnyGeocodingFeatures
     }
     \endcode
@@ -746,7 +741,7 @@ bool QDeclarativeGeoServiceProviderRequirements::matches(const QGeoServiceProvid
     \instantiates QDeclarativeGeoServiceProviderParameter
     \inqmlmodule QtLocation
     \ingroup qml-QtLocation5-common
-    \since Qt Location 5.0
+    \since Qt Location 5.5
 
     \brief The PluginParameter type describes a parameter to a \l Plugin.
 
@@ -761,14 +756,14 @@ bool QDeclarativeGeoServiceProviderRequirements::matches(const QGeoServiceProvid
 
     \section2 Example Usage
 
-    The following example shows an instantiation of the \l {Qt Location Nokia Plugin}{Nokia} plugin
+    The following example shows an instantiation of the \l {Qt Location HERE Plugin}{HERE} plugin
     with a mapping API \e app_id and \e token pair specific to the application.
 
     \code
     Plugin {
-        name: "nokia"
-        PluginParameter { name: "app_id"; value: "EXAMPLE_API_ID" }
-        PluginParameter { name: "token"; value: "EXAMPLE_TOKEN_123" }
+        name: "here"
+        PluginParameter { name: "here.app_id"; value: "EXAMPLE_API_ID" }
+        PluginParameter { name: "here.token"; value: "EXAMPLE_TOKEN_123" }
     }
     \endcode
 */
