@@ -1,39 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -53,40 +48,29 @@
 //
 
 #include <QObject>
-#include <QSet>
-#include <QSharedPointer>
-#include <QSize>
 #include <QtLocation/qlocationglobal.h>
-#include <QtPositioning/private/qdoublevector2d_p.h>
 
 QT_BEGIN_NAMESPACE
 
-class QGeoCoordinate;
 class QGeoCameraData;
 class QGeoTileSpec;
-
 class QDoubleVector2D;
-
-class QGLSceneNode;
-class QGLCamera;
-class QGLPainter;
-class QGLTexture2D;
 class QGeoTileTexture;
-
-class QPointF;
-
+class QSGNode;
+class QQuickWindow;
 class QGeoMapScenePrivate;
 
 class Q_LOCATION_EXPORT QGeoMapScene : public QObject
 {
     Q_OBJECT
+    Q_DECLARE_PRIVATE(QGeoMapScene)
 public:
-    QGeoMapScene();
+    explicit QGeoMapScene(QObject *parent = 0);
     virtual ~QGeoMapScene();
 
     void setScreenSize(const QSize &size);
     void setTileSize(int tileSize);
-    void setCameraData(const QGeoCameraData &cameraData_);
+    void setCameraData(const QGeoCameraData &cameraData);
 
     void setVisibleTiles(const QSet<QGeoTileSpec> &tiles);
 
@@ -94,12 +78,10 @@ public:
 
     void addTile(const QGeoTileSpec &spec, QSharedPointer<QGeoTileTexture> texture);
 
-    QDoubleVector2D screenPositionToMercator(const QDoubleVector2D &pos) const;
-    QDoubleVector2D mercatorToScreenPosition(const QDoubleVector2D &mercator) const;
+    QDoubleVector2D itemPositionToMercator(const QDoubleVector2D &pos) const;
+    QDoubleVector2D mercatorToItemPosition(const QDoubleVector2D &mercator) const;
 
-    QGLCamera *camera() const;
-    QGLSceneNode *sceneNode() const;
-    void paintGL(QGLPainter *painter);
+    QSGNode *updateSceneGraph(QSGNode *oldNode, QQuickWindow *window);
 
     bool verticalLock() const;
     QSet<QGeoTileSpec> texturedTiles();
@@ -108,8 +90,6 @@ Q_SIGNALS:
     void newTilesVisible(const QSet<QGeoTileSpec> &newTiles);
 
 private:
-    QGeoMapScenePrivate *d_ptr;
-    Q_DECLARE_PRIVATE(QGeoMapScene)
     Q_DISABLE_COPY(QGeoMapScene)
 };
 
