@@ -1,39 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -52,7 +47,7 @@ QT_BEGIN_NAMESPACE
     \inmodule QtLocation
     \ingroup QtLocation-places
     \ingroup QtLocation-places-manager
-    \since Qt Location 5.0
+    \since 5.5
 
     \brief The QPlaceManager class provides the interface which allows clients to access
     places stored in a particular backend.
@@ -97,7 +92,7 @@ QT_BEGIN_NAMESPACE
     See \l {Initializing a manager} for an example on how to create a manager.
 
 
-    \section1 Asynchronous Interface.
+    \section1 Asynchronous Interface
     The QPlaceManager class provides an abstraction of the datastore which contains place information.
     The functions provided by the QPlaceManager and primarily asynchronous and follow
     a request-reply model.   Typically a request is given to the manager, consisting
@@ -146,7 +141,7 @@ QPlaceManager::QPlaceManager(QPlaceManagerEngine *engine, QObject *parent)
         d->setParent(this);
         d->d_ptr->manager = this;
 
-        qRegisterMetaType<QPlaceCategory>("QPlaceCategory");
+        qRegisterMetaType<QPlaceCategory>();
 
         connect(d, SIGNAL(finished(QPlaceReply*)), this, SIGNAL(finished(QPlaceReply*)));
         connect(d, SIGNAL(error(QPlaceReply*,QPlaceReply::Error)),
@@ -160,11 +155,11 @@ QPlaceManager::QPlaceManager(QPlaceManagerEngine *engine, QObject *parent)
                 this, SIGNAL(placeRemoved(QString)), Qt::QueuedConnection);
 
         connect(d, SIGNAL(categoryAdded(QPlaceCategory,QString)),
-                this, SIGNAL(categoryAdded(QPlaceCategory,QString)), Qt::QueuedConnection);
+                this, SIGNAL(categoryAdded(QPlaceCategory,QString)));
         connect(d, SIGNAL(categoryUpdated(QPlaceCategory,QString)),
-                this, SIGNAL(categoryUpdated(QPlaceCategory,QString)), Qt::QueuedConnection);
+                this, SIGNAL(categoryUpdated(QPlaceCategory,QString)));
         connect(d, SIGNAL(categoryRemoved(QString,QString)),
-                this, SIGNAL(categoryRemoved(QString,QString)), Qt::QueuedConnection);
+                this, SIGNAL(categoryRemoved(QString,QString)));
         connect(d, SIGNAL(dataChanged()),
                 this, SIGNAL(dataChanged()), Qt::QueuedConnection);
     } else {
@@ -208,14 +203,13 @@ QPlaceDetailsReply *QPlaceManager::getPlaceDetails(const QString &placeId) const
 }
 
 /*!
-    Retrieves content for the place corresponding to \a placeId, according to the parameters specified in
-    \a request.
+    Retrieves content for a place according to the parameters specified in \a request.
 
     See \l {Fetching Rich Content} for an example of usage.
 */
-QPlaceContentReply *QPlaceManager::getPlaceContent(const QString &placeId, const QPlaceContentRequest &request) const
+QPlaceContentReply *QPlaceManager::getPlaceContent(const QPlaceContentRequest &request) const
 {
-    return d->getPlaceContent(placeId, request);
+    return d->getPlaceContent(request);
 }
 
 /*!
