@@ -1,39 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the QtLocation module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -55,7 +50,7 @@ QT_BEGIN_NAMESPACE
     \ingroup QtLocation-impl
     \ingroup QtLocation-places
     \ingroup QtLocation-places-manager
-    \since Qt Location 5.0
+    \since 5.5
 
     \brief The QPlaceManagerEngine class provides an interface for
     implementers of QGeoServiceProvider plugins who want to provide access to place
@@ -78,8 +73,8 @@ QPlaceManagerEngine::QPlaceManagerEngine(const QVariantMap &parameters,
                                          QObject *parent)
 :   QObject(parent), d_ptr(new QPlaceManagerEnginePrivate)
 {
-    qRegisterMetaType<QPlaceReply::Error>("QPlaceReply::Error");
-    qRegisterMetaType<QPlaceReply *>("QPlaceReply *");
+    qRegisterMetaType<QPlaceReply::Error>();
+    qRegisterMetaType<QPlaceReply *>();
     Q_UNUSED(parameters)
 }
 
@@ -167,8 +162,8 @@ QPlaceSearchReply *QPlaceManagerEngine::search(const QPlaceSearchRequest &reques
 {
     Q_UNUSED(request)
 
-    return new QPlaceSearchReplyUnsupported(QStringLiteral("Place search is not supported."),
-                                            this);
+    return new QPlaceSearchReplyUnsupported(QPlaceReply::UnsupportedError,
+                                            QStringLiteral("Place search is not supported."), this);
 }
 
 /*!
