@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -42,7 +34,7 @@
 #include <QtCore/QString>
 #include <QtTest/QtTest>
 
-#include <qgeoaddress.h>
+#include <QtPositioning/qgeoaddress.h>
 
 QT_USE_NAMESPACE
 
@@ -97,8 +89,8 @@ void tst_QGeoAddress::textTest()
 {
     QGeoAddress address;
     QVERIFY(address.text().isEmpty());
-    address.setText(QLatin1String("123 Fake Street\nSpringfield"));
-    QCOMPARE(address.text(), QLatin1String("123 Fake Street\nSpringfield"));
+    address.setText(QStringLiteral("123 Fake Street\nSpringfield"));
+    QCOMPARE(address.text(), QStringLiteral("123 Fake Street\nSpringfield"));
 }
 
 void tst_QGeoAddress::cityTest()
@@ -201,7 +193,7 @@ void tst_QGeoAddress::generatedText()
     streetOnly.setStreet("street");
     streetOnly.setCountryCode(countryCode);
 
-    QCOMPARE(streetOnly.text(), QLatin1String("street"));
+    QCOMPARE(streetOnly.text(), QStringLiteral("street"));
 
     QGeoAddress cityOnly;
     cityOnly.setCity("city");
@@ -209,7 +201,7 @@ void tst_QGeoAddress::generatedText()
     if (countryCode == QLatin1String("CYM") || countryCode == QLatin1String("IRL"))
         QCOMPARE(cityOnly.text(), QString());
     else
-        QCOMPARE(cityOnly.text(), QLatin1String("city"));
+        QCOMPARE(cityOnly.text(), QStringLiteral("city"));
 
     QGeoAddress postalCodeOnly;
     postalCodeOnly.setPostalCode("postcode");
@@ -528,39 +520,39 @@ void tst_QGeoAddress::emptyClearTest()
     QGeoAddress testObj;
     QVERIFY(testObj.isEmpty());
 
-    testObj.setCountry(QLatin1String("country"));
+    testObj.setCountry(QStringLiteral("country"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setCountryCode(QLatin1String("countryCode"));
+    testObj.setCountryCode(QStringLiteral("countryCode"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setState(QLatin1String("state"));
+    testObj.setState(QStringLiteral("state"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setCounty(QLatin1String("county"));
+    testObj.setCounty(QStringLiteral("county"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setCity(QLatin1String("city"));
+    testObj.setCity(QStringLiteral("city"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setDistrict(QLatin1String("district"));
+    testObj.setDistrict(QStringLiteral("district"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setPostalCode(QLatin1String("postalCode"));
+    testObj.setPostalCode(QStringLiteral("postalCode"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setStreet(QLatin1String("street"));
+    testObj.setStreet(QStringLiteral("street"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
-    testObj.setText(QLatin1String("formatted address"));
+    testObj.setText(QStringLiteral("formatted address"));
     QVERIFY(!testObj.isEmpty());
     testObj.clear();
 
