@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -80,15 +72,15 @@ private:
         double step = 1 / (std::pow(2.0, 4.0) * 4);
 
         QString row = pti.xyString;
-        row += QLatin1String(" - ");
+        row += QStringLiteral(" - ");
         row += pti.zoomString;
-        row += QLatin1String(" - (");
+        row += QStringLiteral(" - (");
         row += QString::number(xOffset);
-        row += QLatin1String(",");
+        row += QStringLiteral(",");
         row += QString::number(yOffset);
-        row += QLatin1String(") - ");
+        row += QStringLiteral(") - ");
         row += pti.wString;
-        row += QLatin1String(" x ");
+        row += QStringLiteral(" x ");
         row += pti.hString;
 
         QList<int> xRow;
@@ -132,13 +124,13 @@ private slots:
         ct.setTileSize(16);
         ct.setCamera(camera);
         ct.setScreenSize(QSize(32, 32));
-        ct.setMapType(QGeoMapType(QGeoMapType::StreetMap, "street map", "street map", false, 1));
+        ct.setMapType(QGeoMapType(QGeoMapType::StreetMap, "street map", "street map", false, false, 1));
 
-        QSet<QGeoTileSpec> tiles1 = ct.tiles();
+        QSet<QGeoTileSpec> tiles1 = ct.visibleTiles();
 
         ct.setPluginString("pluginA");
 
-        QSet<QGeoTileSpec> tiles2 = ct.tiles();
+        QSet<QGeoTileSpec> tiles2 = ct.visibleTiles();
 
         typedef QSet<QGeoTileSpec>::const_iterator iter;
         iter i1 = tiles1.constBegin();
@@ -155,7 +147,7 @@ private slots:
 
         ct.setPluginString("pluginB");
 
-        QSet<QGeoTileSpec> tiles3 = ct.tiles();
+        QSet<QGeoTileSpec> tiles3 = ct.visibleTiles();
 
         iter i2 = tiles2.constBegin();
         iter end2 = tiles2.constEnd();
@@ -183,12 +175,12 @@ private slots:
         ct.setScreenSize(QSize(32, 32));
         ct.setPluginString("pluginA");
 
-        QSet<QGeoTileSpec> tiles1 = ct.tiles();
+        QSet<QGeoTileSpec> tiles1 = ct.visibleTiles();
 
-        QGeoMapType mapType1 = QGeoMapType(QGeoMapType::StreetMap, "street map", "street map", false, 1);
+        QGeoMapType mapType1 = QGeoMapType(QGeoMapType::StreetMap, "street map", "street map", false, false, 1);
         ct.setMapType(mapType1);
 
-        QSet<QGeoTileSpec> tiles2 = ct.tiles();
+        QSet<QGeoTileSpec> tiles2 = ct.visibleTiles();
 
         typedef QSet<QGeoTileSpec>::const_iterator iter;
         iter i1 = tiles1.constBegin();
@@ -203,10 +195,10 @@ private slots:
 
         QCOMPARE(tiles2, tiles2_check);
 
-        QGeoMapType mapType2 = QGeoMapType(QGeoMapType::StreetMap, "satellite map", "satellite map", false, 2);
+        QGeoMapType mapType2 = QGeoMapType(QGeoMapType::StreetMap, "satellite map", "satellite map", false, false, 2);
         ct.setMapType(mapType2);
 
-        QSet<QGeoTileSpec> tiles3 = ct.tiles();
+        QSet<QGeoTileSpec> tiles3 = ct.visibleTiles();
 
         iter i2 = tiles2.constBegin();
         iter end2 = tiles2.constEnd();
@@ -248,7 +240,7 @@ private slots:
         for (int i = 0; i < tilesX.size(); ++i)
             tiles.insert(QGeoTileSpec("", 0, static_cast<int>(std::floor(zoom)), tilesX.at(i), tilesY.at(i)));
 
-        QCOMPARE(ct.tiles(), tiles);
+        QCOMPARE(ct.visibleTiles(), tiles);
     }
 
     void tilesPositions_data()
@@ -362,8 +354,8 @@ private slots:
 
         pti.w = t - 1;
         pti.h = t - 1;
-        pti.wString = QLatin1String("(1T - 1)");
-        pti.hString = QLatin1String("(1T - 1)");
+        pti.wString = QStringLiteral("(1T - 1)");
+        pti.hString = QStringLiteral("(1T - 1)");
 
         /*
 
@@ -522,70 +514,70 @@ private slots:
         right_tm1w << 2;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tm1x, mid_tm1w, mid_tm1x, mid_tm1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tm1x, mid_tm1w, top_tm1x, top_tm1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tm1x, mid_tm1w, bottom_tm1x, bottom_tm1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tm1x, left_tm1w, mid_tm1x, mid_tm1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tm1x, right_tm1w, mid_tm1x, mid_tm1w);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tm1x, mid_tm1w, mid_tm1x, mid_tm1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tm1x, mid_tm1w, top_tm1x, top_tm1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tm1x, mid_tm1w, bottom_tm1x, bottom_tm1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tm1x, left_tm1w, mid_tm1x, mid_tm1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tm1x, right_tm1w, mid_tm1x, mid_tm1w);
 
@@ -606,8 +598,8 @@ private slots:
 
         pti.w = t;
         pti.h = t;
-        pti.wString = QLatin1String("1T");
-        pti.hString = QLatin1String("1T");
+        pti.wString = QStringLiteral("1T");
+        pti.hString = QStringLiteral("1T");
 
         /*
 
@@ -766,70 +758,70 @@ private slots:
         right_tw << 2;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tx, mid_tw, mid_tx, mid_tw);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tx, mid_tw, top_tx, top_tw);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tx, mid_tw, bottom_tx, bottom_tw);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tx, left_tw, mid_tx, mid_tw);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tx, right_tw, mid_tx, mid_tw);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tx, mid_tw, mid_tx, mid_tw);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tx, mid_tw, top_tx, top_tw);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tx, mid_tw, bottom_tx, bottom_tw);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tx, left_tw, mid_tx, mid_tw);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tx, right_tw, mid_tx, mid_tw);
 
@@ -850,8 +842,8 @@ private slots:
 
         pti.w = t + 1;
         pti.h = t + 1;
-        pti.wString = QLatin1String("(1T + 1)");
-        pti.hString = QLatin1String("(1T + 1)");
+        pti.wString = QStringLiteral("(1T + 1)");
+        pti.hString = QStringLiteral("(1T + 1)");
 
         /*
 
@@ -1010,70 +1002,70 @@ private slots:
         right_tp1w << 2;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tp1x, mid_tp1w, mid_tp1x, mid_tp1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tp1x, mid_tp1w, top_tp1x, top_tp1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tp1x, mid_tp1w, bottom_tp1x, bottom_tp1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tp1x, left_tp1w, mid_tp1x, mid_tp1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tp1x, right_tp1w, mid_tp1x, mid_tp1w);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_tp1x, mid_tp1w, mid_tp1x, mid_tp1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_tp1x, mid_tp1w, top_tp1x, top_tp1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_tp1x, mid_tp1w, bottom_tp1x, bottom_tp1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_tp1x, left_tp1w, mid_tp1x, mid_tp1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_tp1x, right_tp1w, mid_tp1x, mid_tp1w);
 
@@ -1094,8 +1086,8 @@ private slots:
 
         pti.w = 2 * t - 1;
         pti.h = 2 * t - 1;
-        pti.wString = QLatin1String("(2T - 1)");
-        pti.hString = QLatin1String("(2T - 1)");
+        pti.wString = QStringLiteral("(2T - 1)");
+        pti.hString = QStringLiteral("(2T - 1)");
 
         /*
                 offset = 0
@@ -1253,70 +1245,70 @@ private slots:
         right_t2m1w << 2;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, mid_t2m1x, mid_t2m1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, top_t2m1x, top_t2m1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, bottom_t2m1x, bottom_t2m1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2m1x, left_t2m1w, mid_t2m1x, mid_t2m1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2m1x, right_t2m1w, mid_t2m1x, mid_t2m1w);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, mid_t2m1x, mid_t2m1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, top_t2m1x, top_t2m1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2m1x, mid_t2m1w, bottom_t2m1x, bottom_t2m1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2m1x, left_t2m1w, mid_t2m1x, mid_t2m1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2m1x, right_t2m1w, mid_t2m1x, mid_t2m1w);
 
@@ -1338,8 +1330,8 @@ private slots:
 
         pti.w = 2 * t;
         pti.h = 2 * t;
-        pti.wString = QLatin1String("2T");
-        pti.hString = QLatin1String("2T");
+        pti.wString = QStringLiteral("2T");
+        pti.hString = QStringLiteral("2T");
 
         /*
 
@@ -1498,70 +1490,70 @@ private slots:
         right_t2w << 4;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2x, mid_t2w, mid_t2x, mid_t2w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2x, mid_t2w, top_t2x, top_t2w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2x, mid_t2w, bottom_t2x, bottom_t2w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2x, left_t2w, mid_t2x, mid_t2w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2x, right_t2w, mid_t2x, mid_t2w);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2x, mid_t2w, mid_t2x, mid_t2w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2x, mid_t2w, top_t2x, top_t2w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2x, mid_t2w, bottom_t2x, bottom_t2w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2x, left_t2w, mid_t2x, mid_t2w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2x, right_t2w, mid_t2x, mid_t2w);
 
@@ -1582,8 +1574,8 @@ private slots:
 
         pti.w = 2 * t + 1;
         pti.h = 2 * t + 1;
-        pti.wString = QLatin1String("(2T + 1)");
-        pti.hString = QLatin1String("(2T + 1)");
+        pti.wString = QStringLiteral("(2T + 1)");
+        pti.hString = QStringLiteral("(2T + 1)");
 
         /*
 
@@ -1742,70 +1734,70 @@ private slots:
         right_t2p1w << 4;
 
         pti.zoom = 4.0;
-        pti.zoomString = QLatin1String("int zoom");
+        pti.zoomString = QStringLiteral("int zoom");
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, mid_t2p1x, mid_t2p1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, top_t2p1x, top_t2p1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, bottom_t2p1x, bottom_t2p1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2p1x, left_t2p1w, mid_t2p1x, mid_t2p1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2p1x, right_t2p1w, mid_t2p1x, mid_t2p1w);
 
         pti.zoom = 4.5;
-        pti.zoomString = QLatin1String("frac zoom");
+        pti.zoomString = QStringLiteral("frac zoom");
         pti.w = pti.w * std::pow(2.0, 0.5);
         pti.h = pti.h * std::pow(2.0, 0.5);
 
         pti.x = 0.5;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("middle");
+        pti.xyString = QStringLiteral("middle");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, mid_t2p1x, mid_t2p1w);
 
         pti.x = 0.5;
         pti.y = 0.0;
-        pti.xyString = QLatin1String("top");
+        pti.xyString = QStringLiteral("top");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, top_t2p1x, top_t2p1w);
 
         pti.x = 0.5;
         pti.y = 15.0 / 16.0;
-        pti.xyString = QLatin1String("bottom");
+        pti.xyString = QStringLiteral("bottom");
 
         test_group(pti, mid_t2p1x, mid_t2p1w, bottom_t2p1x, bottom_t2p1w);
 
         pti.x = 0.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("left");
+        pti.xyString = QStringLiteral("left");
 
         test_group(pti, left_t2p1x, left_t2p1w, mid_t2p1x, mid_t2p1w);
 
         pti.x = 15.0 / 16.0;
         pti.y = 0.5;
-        pti.xyString = QLatin1String("right");
+        pti.xyString = QStringLiteral("right");
 
         test_group(pti, right_t2p1x, right_t2p1w, mid_t2p1x, mid_t2p1w);
     }
