@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -50,9 +42,6 @@
 #include <QtPositioning/private/qgeoprojection_p.h>
 #include <QtPositioning/private/qdoublevector2d_p.h>
 
-#include <Qt3D/qglscenenode.h>
-#include <Qt3D/qgltexture2d.h>
-
 #include <qtest.h>
 
 #include <QList>
@@ -304,7 +293,7 @@ class tst_QGeoMapScene : public QObject
             mapScene.setCameraData(camera);
             QVERIFY(!mapScene.verticalLock());
             mapScene.setUseVerticalLock(true);
-            mapScene.setVisibleTiles(ct.tiles());
+            mapScene.setVisibleTiles(ct.visibleTiles());
             QVERIFY(mapScene.verticalLock());
 
             // Test the case when setting vertical lock has no effect
@@ -314,7 +303,7 @@ class tst_QGeoMapScene : public QObject
             mapScene2.setCameraData(camera);
             QVERIFY(!mapScene2.verticalLock());
             mapScene2.setUseVerticalLock(true);
-            mapScene2.setVisibleTiles(ct.tiles());
+            mapScene2.setVisibleTiles(ct.visibleTiles());
             QVERIFY(!mapScene2.verticalLock());
         }
 
@@ -344,10 +333,10 @@ class tst_QGeoMapScene : public QObject
             mapGeometry.setTileSize(tileSize);
             mapGeometry.setScreenSize(QSize(screenWidth,screenHeight));
             mapGeometry.setCameraData(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
+            mapGeometry.setVisibleTiles(ct.visibleTiles());
 
             QDoubleVector2D point(screenX,screenY);
-            QDoubleVector2D mecartorPos = mapGeometry.screenPositionToMercator(point);
+            QDoubleVector2D mecartorPos = mapGeometry.itemPositionToMercator(point);
 
             QCOMPARE(mecartorPos.x(),mercatorX);
             QCOMPARE(mecartorPos.y(),mercatorY);
@@ -384,10 +373,10 @@ class tst_QGeoMapScene : public QObject
             mapGeometry.setTileSize(tileSize);
             mapGeometry.setScreenSize(QSize(screenWidth,screenHeight));
             mapGeometry.setCameraData(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
+            mapGeometry.setVisibleTiles(ct.visibleTiles());
 
             QDoubleVector2D mercatorPos(mercatorX, mercatorY);
-            QPointF point = mapGeometry.mercatorToScreenPosition(mercatorPos).toPointF();
+            QPointF point = mapGeometry.mercatorToItemPosition(mercatorPos).toPointF();
 
             QCOMPARE(point.x(), screenX);
             QCOMPARE(point.y(), screenY);
@@ -397,86 +386,6 @@ class tst_QGeoMapScene : public QObject
             populateScreenMercatorData();
         }
 
-        void cameraMovementAndTileUpdate(){
-            QGeoCameraData camera;
-            camera.setZoomLevel(4.0);
-            camera.setCenter(QGeoProjection::mercatorToCoord(QDoubleVector2D(0.5, 0.5)));
-
-            QGeoMapScene mapGeometry;
-            mapGeometry.setTileSize(16);
-            mapGeometry.setScreenSize(QSize(16,16));
-            mapGeometry.setCameraData(camera);
-
-            QGeoCameraTiles ct;
-            ct.setMaximumZoomLevel(8);
-            ct.setTileSize(16);
-            ct.setCamera(camera);
-            ct.setScreenSize(QSize(16,16));
-            mapGeometry.setVisibleTiles(ct.tiles());
-
-            int sideLength = 1 << static_cast<int>(floor(camera.zoomLevel()));
-            double quaterTile = 1.0 / (sideLength * 4.0);
-
-            // test that there are no scene nodes initially
-            QGLSceneNode* node = mapGeometry.sceneNode();
-            QCOMPARE(node->children().count(), 0);
-
-            // the camera is currently centered on top-left corner of the middle tile
-            // (so 4 tiles should be visible and added to map geometry)
-            QSharedPointer<QGeoTileTexture> tt(new QGeoTileTexture);
-            tt->texture = new QGLTexture2D();
-            foreach (QGeoTileSpec spec, ct.tiles())
-                mapGeometry.addTile(spec, tt); // add tiles with empty texture
-            QGLSceneNode* node2 = mapGeometry.sceneNode();
-            QCOMPARE(node2->children().count(), ct.tiles().count());
-            QCOMPARE(node2->children().count(), 4);
-
-            // move camera slightly in x direction but within the same tile bounds
-            // and verify that no new tiles are added through addTile
-            camera.setCenter(QGeoProjection::mercatorToCoord(QDoubleVector2D(0.5 + quaterTile, 0.5)));
-            mapGeometry.setCameraData(camera);
-            ct.setCamera(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
-            foreach (QGeoTileSpec spec, ct.tiles())
-                mapGeometry.addTile(spec, tt);
-            QGLSceneNode* node3 = mapGeometry.sceneNode();
-            // test to see that there are still only 4 tiles in the map geometry
-            QCOMPARE(node3->children().count(), ct.tiles().count());
-            QCOMPARE(node3->children().count(), 4);
-
-            // move camera further in x to align with edges of middle tile so that 6 tiles are fetched
-            camera.setCenter(QGeoProjection::mercatorToCoord(QDoubleVector2D(0.5 + quaterTile*2, 0.5)));
-            mapGeometry.setCameraData(camera);
-            ct.setCamera(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
-            foreach (QGeoTileSpec spec, ct.tiles())
-                mapGeometry.addTile(spec, tt);
-            QGLSceneNode* node4 = mapGeometry.sceneNode();
-            QCOMPARE(node4->children().count(), ct.tiles().count());
-            QCOMPARE(node4->children().count(), 6);
-
-            // move camera further in x so that the 2 tiles on the left are now removed
-            camera.setCenter(QGeoProjection::mercatorToCoord(QDoubleVector2D(0.5 + quaterTile*4, 0.5)));
-            mapGeometry.setCameraData(camera);
-            ct.setCamera(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
-            foreach (QGeoTileSpec spec, ct.tiles())
-                mapGeometry.addTile(spec, tt);
-            QGLSceneNode* node5 = mapGeometry.sceneNode();
-            QCOMPARE(node5->children().count(), ct.tiles().count());
-            QCOMPARE(node5->children().count(), 4);
-
-           // test adding tiles with wrapping and clipping
-            camera.setCenter(QGeoProjection::mercatorToCoord(QDoubleVector2D(0.0, 0.0)));
-            mapGeometry.setCameraData(camera);
-            ct.setCamera(camera);
-            mapGeometry.setVisibleTiles(ct.tiles());
-            foreach (QGeoTileSpec spec, ct.tiles())
-                mapGeometry.addTile(spec, tt);
-            QGLSceneNode* node6 = mapGeometry.sceneNode();
-            QCOMPARE(node6->children().count(), ct.tiles().count());
-            QCOMPARE(node6->children().count(), 2);
-        }
 };
 
 QTEST_GUILESS_MAIN(tst_QGeoMapScene)
